@@ -154,6 +154,7 @@ VERSION_REQUIREMENT_EMPTY_OUTPUT = SpecifierSet(">=0.1.6")
 
 # Arguments provided to every Ruff invocation.
 CHECK_ARGS = [
+    "check",
     "--force-exclude",
     "--no-cache",
     "--no-fix",
@@ -393,7 +394,7 @@ def _create_notebook_json(notebook_document: NotebookDocument) -> str:
             cells.append(
                 {
                     "cell_type": "code",
-                    "metadata": None,
+                    "metadata": {},
                     "outputs": [],
                     "source": cell_document.source,
                 }
@@ -402,7 +403,7 @@ def _create_notebook_json(notebook_document: NotebookDocument) -> str:
             cells.append(
                 {
                     "cell_type": "markdown",
-                    "metadata": None,
+                    "metadata": {},
                     "source": cell_document.source,
                 }
             )
@@ -427,7 +428,7 @@ def _create_single_cell_notebook_json(source: str) -> str:
             "cells": [
                 {
                     "cell_type": "code",
-                    "metadata": None,
+                    "metadata": {},
                     "outputs": [],
                     "source": source,
                 }
@@ -449,7 +450,7 @@ async def did_open(params: DidOpenTextDocumentParams) -> None:
     )
     settings = _get_settings_by_document(document.path)
     if not lint_enable(settings):
-        return
+        return None
 
     diagnostics = await _lint_document_impl(document, settings)
     LSP_SERVER.publish_diagnostics(document.uri, diagnostics)
@@ -469,7 +470,7 @@ async def did_save(params: DidSaveTextDocumentParams) -> None:
     text_document = LSP_SERVER.workspace.get_text_document(params.text_document.uri)
     settings = _get_settings_by_document(text_document.path)
     if not lint_enable(settings):
-        return
+        return None
 
     if lint_run(settings) in (
         Run.OnType,
@@ -486,7 +487,7 @@ async def did_change(params: DidChangeTextDocumentParams) -> None:
     text_document = LSP_SERVER.workspace.get_text_document(params.text_document.uri)
     settings = _get_settings_by_document(text_document.path)
     if not lint_enable(settings):
-        return
+        return None
 
     if lint_run(settings) == Run.OnType:
         document = Document.from_text_document(text_document)
@@ -502,12 +503,12 @@ async def did_open_notebook(params: DidOpenNotebookDocumentParams) -> None:
     )
     if notebook_document is None:
         log_warning(f"No notebook document found for {params.notebook_document.uri!r}")
-        return
+        return None
 
     document = Document.from_notebook_document(notebook_document)
     settings = _get_settings_by_document(document.path)
     if not lint_enable(settings):
-        return
+        return None
 
     diagnostics = await _lint_document_impl(document, settings)
 
@@ -571,12 +572,12 @@ async def _did_change_or_save_notebook(
     )
     if notebook_document is None:
         log_warning(f"No notebook document found for {notebook_uri!r}")
-        return
+        return None
 
     document = Document.from_notebook_document(notebook_document)
     settings = _get_settings_by_document(document.path)
     if not lint_enable(settings):
-        return
+        return None
 
     if lint_run(settings) in run_types:
         cell_diagnostics = _group_diagnostics_by_cell(
@@ -613,7 +614,11 @@ async def _lint_document_impl(
             show_error(f"Ruff: Lint failed ({result.stderr.decode('utf-8')})")
         return []
 
-    return _parse_output(result.stdout) if result.stdout else []
+    return (
+        _parse_output(result.stdout, settings.get("showSyntaxErrors", True))
+        if result.stdout
+        else []
+    )
 
 
 def _parse_fix(content: Fix | LegacyFix | None) -> Fix | None:
@@ -648,7 +653,7 @@ def _parse_fix(content: Fix | LegacyFix | None) -> Fix | None:
         return fix
 
 
-def _parse_output(content: bytes) -> list[Diagnostic]:
+def _parse_output(content: bytes, show_syntax_errors: bool) -> list[Diagnostic]:
     """Parse Ruff's JSON output."""
     diagnostics: list[Diagnostic] = []
 
@@ -699,6 +704,8 @@ def _parse_output(content: bytes) -> list[Diagnostic]:
     # Cell represents the cell number in a Notebook Document. It is null for normal
     # Python files.
     for check in json.loads(content):
+        if not show_syntax_errors and check["code"] is None:
+            continue
         start = Position(
             line=max([int(check["location"]["row"]) - 1, 0]),
             character=int(check["location"]["column"]) - 1,
@@ -749,6 +756,7 @@ def _get_severity(code: str) -> DiagnosticSeverity:
         "F821",  # undefined name `name`
         "E902",  # `IOError`
         "E999",  # `SyntaxError`
+        None,  # `SyntaxError` as of Ruff v0.5.0
     }:
         return DiagnosticSeverity.Error
     else:
@@ -1173,11 +1181,11 @@ async def apply_autofix(arguments: tuple[TextDocument]):
     document = Document.from_uri(uri)
     settings = _get_settings_by_document(document.path)
     if not lint_enable(settings):
-        return
+        return None
 
     workspace_edit = await _fix_document_impl(document, settings)
     if workspace_edit is None:
-        return
+        return None
     LSP_SERVER.apply_edit(workspace_edit, "Ruff: Fix all auto-fixable problems")
 
 
@@ -1188,7 +1196,7 @@ async def apply_organize_imports(arguments: tuple[TextDocument]):
     settings = _get_settings_by_document(document.path)
     workspace_edit = await _fix_document_impl(document, settings, only=["I001", "I002"])
     if workspace_edit is None:
-        return
+        return None
     LSP_SERVER.apply_edit(workspace_edit, "Ruff: Format imports")
 
 
@@ -1582,8 +1590,7 @@ def initialize(params: InitializeParams) -> None:
         f"{json.dumps(workspace_settings, indent=4, ensure_ascii=False)}"
     )
     log_to_output(
-        f"Global settings: "
-        f"{json.dumps(global_settings, indent=4, ensure_ascii=False)}"
+        f"Global settings: {json.dumps(global_settings, indent=4, ensure_ascii=False)}"
     )
 
     # Preserve any "global" settings.
@@ -1660,7 +1667,7 @@ def _update_workspace_settings(settings: list[WorkspaceSettings]) -> None:
             "workspacePath": workspace_path,
             "workspace": uris.from_fs_path(workspace_path),
         }
-        return
+        return None
 
     for setting in settings:
         if "workspace" in setting:
@@ -1764,7 +1771,10 @@ def _find_ruff_binary_path(settings: WorkspaceSettings) -> str:
 
     if settings["path"]:
         # 'path' setting takes priority over everything.
-        for path in settings["path"]:
+        paths = settings["path"]
+        if isinstance(paths, str):
+            paths = [paths]
+        for path in paths:
             path = os.path.expanduser(os.path.expandvars(path))
             if os.path.exists(path):
                 log_to_output(f"Using 'path' setting: {path}")
